Package: UNDO
Type: Package
Title: Unsupervised Deconvolution of Tumor-Stromal Mixed Expressions
Version: 1.53.0
Date: 2014-07-17
Author: Niya Wang <wangny@vt.edu>
Maintainer: Niya Wang <wangny@vt.edu>
Depends: R (>= 2.15.2), methods, BiocGenerics, Biobase
Imports: MASS, boot, nnls, stats, utils
biocViews: Software
Description: UNDO is an R package for unsupervised deconvolution of tumor and stromal mixed expression data. It detects marker genes and deconvolutes the mixing expression data without any prior knowledge.
License: GPL-2
git_url: https://git.bioconductor.org/packages/UNDO
git_branch: devel
git_last_commit: a43bf55
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-30
NeedsCompilation: no
Packaged: 2025-10-30 23:32:22 UTC; biocbuild
